package Unicorn::Manager::Types;

# TODO collection of coderefs to be used as type constraints


=head1 NAME

Unicorn::Manager::Types - Types to be used by Unicorn

=head1 VERSION

Version 0.02

=head1 SYNOPSIS

Currently containing nothing.

=head1 TYPES

=head1 AUTHOR

Mugen Kenichi, C<< <mugen.kenichi at uninets.eu> >>

=head1 BUGS

Report bugs at:

=over 2

=item * Unicorn::Manager issue tracker

L<https://github.com/mugenken/Unicorn/issues>

=item * support at uninets.eu

C<< <mugen.kenichi at uninets.eu> >>

=back

=head1 SUPPORT

=over 2

=item * Technical support

C<< <mugen.kenichi at uninets.eu> >>

=back

=cut

